#!/bin/sh

#
# Copyright (c) 2024 by Ruediger Stobbe. All rights reserved
#

# use /usr/local/digilith as default
${DIGITAL_LITH_HOME:=/usr/local/digilith}
export DIGITAL_LITH_HOME

java -Xmx6000000k -jar $DIGITAL_LITH_HOME/digitallith.jar
